# API Reference

```{eval-rst}
.. automodule:: pysampled
    :members:
    :special-members:

.. automodule:: pysampled.core
    :members:
    :undoc-members:
    :special-members: __getitem__, __call__
```